@@ -41,12 +41,13 @@ extern int wordcount(char *);
 extern int parse(char *, int, char *, char *, int, int);
 extern int oer_doquery(char *, int level, const char *, ...);
 extern int issamenickandhost(char *, char *, char *, char *);
+extern unsigned int longestword(char *);
+extern unsigned int isgoodquote(char *);
 extern void striplf(char *);
 extern void stripansi(char *);
 extern void stripmirc(char *);
 extern void stripchars(char *, char *);
 extern void stripcntrl(char *);
-extern void safequote(char *);
 extern void oer_debug(int, const char *, ...);
 extern void secondstostring(int, char *, int);
 extern void sortstring(char *);
