@@ -162,6 +162,7 @@ enum WHICHCOMMAND_RETURN_VALUES {
 	OER_WHICHCOMMAND_WALL,
         OER_WHICHCOMMAND_CLONECHANNEL,
         OER_WHICHCOMMAND_SSTATS,
+        OER_WHICHCOMMAND_DATE,
 	OER_WHICHCOMMAND_INVALID
 };
 
@@ -260,8 +261,9 @@ enum OER_TIMED_PRIORITIES {
 #define OER_NICKS_PER_KICK 1
 #define OER_DEFAULT_DELIM "::"
 #define OER_DEFAULT_DELIM_LEN 2
-#define OER_QUOTE_MIN_LENGTH 10
+#define OER_QUOTE_MIN_LENGTH 20
 #define OER_QUOTE_MAX_LENGTH 200
+#define OER_QUOTE_MAX_WORD_LENGTH 20
 #define OER_WAIT_BETWEEN_CONNECTION_ATTEMPTS 15
 #define OER_JOINS 20
 #define OER_PARTS 20
@@ -338,7 +340,7 @@ enum OER_TIMED_PRIORITIES {
 details possibly available on the oer+MySQL console"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
 #define OER_UNKNOWN "unknown"
-#define OER_COPYRIGHT1 "oer+MySQL version 1.0-25, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer+MySQL version 1.0-26, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer+MySQL comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -523,8 +525,8 @@ struct channel {
 	char name[CHANLEN + 1];
 	char mode[CHANLEN + 1];
 	char key[CHANLEN + 1];
+	char limit[CHANLEN + 1];
 	char chanflags[FLAGLEN + 1];
-	int haskey;
 	int nickcount;
 	int setchanmode;
 	int joined;
