@@ -323,7 +323,7 @@ void parseirc(char *serveroutput)
 #endif
 		return;
 	}
-	if(!strcasecmp(command, "433")) {
+	if(!strcasecmp(command, "432") || !strcasecmp(command, "433")) {
                 restpos = 0;
                 if((restpos = parse(restptr, restpos, " ", nick, NICKLEN, 0)) < 0) {
                         return;
@@ -535,6 +535,9 @@ void parseirc(char *serveroutput)
                         if(!gettobek(this, nick) && checkforbadnick(this, nick, userhost)) {
                                 changetobek(this, nick, 1);
                         }
+			if(!gettobek(this, nick) && haschanflags(this, "V") && isopa(userhost)) {
+                                mmode_new(this, mystate->now, "+v", nick);
+                        }
 			if(!gettobek(this, nick) && haschanflags(this, "v") && isvoice(this, userhost)) {
                                 mmode_new(this, mystate->now, "+v", nick);
                         }
@@ -572,6 +575,9 @@ void parseirc(char *serveroutput)
 		if(getrandommsg(this, nick2, NICKLEN, outstring2, HUGESTRINGLEN, 0) < 0) {
 			return;
 		}
+		if(!isgoodquote(outstring2)) {
+			return;
+		}
 		snprintf(outstring3, HUGESTRINGLEN, "\"%s\" (c) %s", outstring2, nick2);
 		sendreply(channel, 1, 0, OER_TIMED_PRIORITY_NORMAL, outstring3);
 		this->last_quote = mystate->now;
@@ -1137,6 +1143,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 	char topic[OER_TOPICLEN + 1];
 	char uptimestring[STRINGLEN + 1];
 	char modeline[CHANLEN + 1];
+	char ts[TINYSTRINGLEN + 1];
 	char *restptr;
 	struct channel *this;
 	struct channel *that;
@@ -1156,7 +1163,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
         }
 	tochan = (isme(target)) ? 0 : 1;
         if(!tochan) {
-                if(!strlen(outstring) || outstring[0] != '#') {
+		if(!isvalidchannel(outstring)) {
                         /* no channel given, continue from here */
                         strncpy(channel, "<NONE>", CHANLEN);
                         restptr = commandline + prevppos;
@@ -2311,9 +2318,38 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
                         return;
                 }
 		secondstostring(mystate->now - mystate->current_server->linkup, uptimestring, STRINGLEN);
-		snprintf(outstring, WRITE_BUFFER_LENGTH, "RX/TX bytes: %d/%d, link connected for %s", mystate->current_server->rx, mystate->current_server->tx, uptimestring);
+		snprintf(outstring, WRITE_BUFFER_LENGTH, "%s RX/TX bytes: %d/%d, link connected for %s", mystate->current_server->serverhost, mystate->current_server->rx, mystate->current_server->tx, uptimestring);
 		sendreply((tochan) ? channel : nick, tochan, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
 		return;
+	case OER_WHICHCOMMAND_DATE:
+#ifdef DEBUG
+                oer_debug(OER_DEBUG_INFO, "parsecommand->DATE\n");
+#endif
+                /* may be NULL */
+                this = getchptr(channel);
+                proceed = (isopa(userhost)) ? 1 : 0;
+                for(that = mystate->channels; that != NULL && !proceed; that = that->next) {
+                        if(haschanflags(that, "U") && !isatleastop(that, nick, userhost)) {
+                                continue;
+                        }
+                        if(isatleastopnow(that, nick, userhost)) {
+                                proceed = 1;
+                        }
+                }
+                /* check if message was sent to a channel and if it was
+                   is "s" flag set */
+                if(tochan && haschanflags(this, "s")) {
+                        proceed = 1;
+                }
+                if(!proceed) {
+                        return;
+                }
+                strncpy(ts, ctime(&mystate->now), TINYSTRINGLEN);
+                striplf(ts);
+                tzset();
+                snprintf(outstring, WRITE_BUFFER_LENGTH, "my date is %s %s %s", ts, tzname[0], tzname[1]);
+                sendreply((tochan) ? channel : nick, tochan, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
+                return;
         case OER_WHICHCOMMAND_INVALID:
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parsecommand->invalid or malformed command %s\n", command);
