@@ -41,10 +41,11 @@ fi
 
 $ECHO "ok"
 $ECHO ""
+
 readln "Do you want to create the database (+ user) for oer+MySQL? [y/N] " "N"
 CREATEDB=$ans
 
-if [ "$CREATEDB" = "y" ]; then
+if [ "$CREATEDB" = "y" -o "$CREATEDB" = "Y" ]; then
     readln "Please specify the host where MySQL is running [localhost] " "localhost"
     HOST=$ans
     readln "Please specify the MySQL admin user [root] " "root"
@@ -111,6 +112,7 @@ if [ "$CREATEDB" = "y" ]; then
     $ECHO ""
     HOSTNAME=`hostname`
     GRANTFOR="$HOSTNAME localhost"
+    $ECHO ""
     for i in $GRANTFOR; do
 	$ECHO -n "Attempting to grant rights to $DBUSER coming from $i... "
 
@@ -147,6 +149,7 @@ if [ "$CREATEDB" = "y" ]; then
 	fi
 
 	$ECHO "ok"
+	$ECHO ""
     done
     $ECHO -n "Attempting to FLUSH PRIVILEGES... "
 
@@ -167,45 +170,54 @@ if [ "$CREATEDB" = "y" ]; then
     fi
 
     $ECHO "ok"
-else
-    readln "Please specify the host where MySQL is running [localhost] " "localhost"
-    HOST=$ans
-    readln "Please specify the database [oerdb] " "oerdb"
-    DB=$ans
-    readln "Please specify the database user [oer] " "oer"
-    DBUSER=$ans
-    stty -$ECHO
-    readln "Please specify password for $DBUSER [] " ""
-    DBUSERPW=$ans
-    stty $ECHO
     $ECHO ""
-    $ECHO ""
-    $ECHO -n "Attempting to connect to $HOST as $DBUSER... "
-
-    if [ "$DBUSERPW" = "" ]; then
-	LOGTHIS=`( $1/mysqladmin -h $HOST -u $DBUSER ping ) 2>&1`
-	RC=$?
-        $ECHO $LOGTHIS >> $LOGTO
-    else
-	LOGTHIS=`( $1/mysqladmin -h $HOST -u $DBUSER -p$DBUSERPW ping ) 2>&1`
-	RC=$?
-        $ECHO $LOGTHIS >> $LOGTO
-    fi
-
-    if [ $RC -eq 1 ]; then
-	$ECHO "failed"
-	$ECHO ""
-        exit 1
-    fi
-
-    $ECHO "ok"
 fi
 
-$ECHO ""
-readln "Do you want to create the initial tables for oer+MySQL? [y/N] " "N"
+if [ "$CREATEDB" = "y" -o "$CREATEDB" = "Y" ]; then
+    readln "Do you want to create the initial tables for oer+MySQL? [Y/n] " "Y"
+else
+    readln "Do you want to create the initial tables for oer+MySQL? [y/N] " "N"
+fi
+
 CREATETABLES=$ans
 
-if [ "$CREATETABLES" = "y" ]; then
+if [ "$CREATETABLES" = "y" -o "$CREATETABLES" = "Y" ]; then
+    if [ "$CREATEDB" = "n" -o "$CREATEDB" = "N" ]; then
+	readln "Please specify the host where MySQL is running [localhost] " "localhost"
+	HOST=$ans
+	readln "Please specify the database [oerdb] " "oerdb"
+	DB=$ans
+	readln "Please specify the database user [oer] " "oer"
+	DBUSER=$ans
+	stty -$ECHO
+	readln "Please specify password for $DBUSER [] " ""
+	DBUSERPW=$ans
+	stty $ECHO
+	$ECHO ""
+	$ECHO ""
+	$ECHO -n "Attempting to connect to $HOST as $DBUSER... "
+	
+	if [ "$DBUSERPW" = "" ]; then
+	    LOGTHIS=`( $1/mysqladmin -h $HOST -u $DBUSER ping ) 2>&1`
+	    RC=$?
+	    $ECHO $LOGTHIS >> $LOGTO
+	else
+	    LOGTHIS=`( $1/mysqladmin -h $HOST -u $DBUSER -p$DBUSERPW ping ) 2>&1`
+	    RC=$?
+	    $ECHO $LOGTHIS >> $LOGTO
+	fi
+	
+	if [ $RC -eq 1 ]; then
+	    $ECHO "failed"
+	    $ECHO ""
+	    exit 1
+	fi
+	
+	$ECHO "ok"
+	$ECHO ""
+    fi
+
+    $ECHO ""
     $ECHO -n "Creating initial tables... "
 
     if [ "$DBUSERPW" = "" ]; then
@@ -228,13 +240,18 @@ if [ "$CREATETABLES" = "y" ]; then
     fi
 
     $ECHO "ok"
+    $ECHO ""
+fi
+
+if [ "$CREATEDB" = "y" -o "$CREATEDB" = "Y" ]; then
+    readln "Do you want to create the initial configuration for oer+MySQL? [Y/n] " "Y"
+else
+    readln "Do you want to create the initial configuration for oer+MySQL? [y/N] " "N"
 fi
 
-$ECHO ""
-readln "Do you want to create the initial configuration for oer+MySQL? [y/N] " "N"
 CREATECONF=$ans
 
-if [ "$CREATECONF" = "y" ]; then
+if [ "$CREATECONF" = "y" -o "$CREATECONF" = "Y" ]; then
     $ECHO ""
     $ECHO "oer+MySQL configuration follows"
     $ECHO ""
@@ -246,7 +263,7 @@ if [ "$CREATECONF" = "y" ]; then
     USERID=$ans
     readln "Please specify user modes [+i] " "+i"
     USERMODES=$ans
-    readln "Please specify bot flags [f] " "f"
+    readln "Please specify bot flags [fn] " "fn"
     BOTFLAGS=$ans
     readln "Please specify command prefix [!] " "!"
     PREFIX=$ans
@@ -257,7 +274,7 @@ if [ "$CREATECONF" = "y" ]; then
     readln "Please specify bot handle [oer] " "oer"
     HANDLE=$ans
     
-    INSERT_CONF="INSERT INTO conf VALUES ('$NICK','$ALTNICK','$USERID','$USERMODES','$BOTFLAGS','$PREFIX','$REALNAME','$VIRTHOST','$HANDLE')"
+    INSERT_CONF="INSERT INTO conf VALUES ('$NICK','$ALTNICK','$USERID','$USERMODES','$BOTFLAGS','$PREFIX','$REALNAME','$VIRTHOST',NULL,NULL,NULL,'$HANDLE')"
 	
     readln "Please specify bot admin handle [EQU] " "EQU"
     ADMIN=$ans
@@ -388,31 +405,34 @@ if [ "$CREATECONF" = "y" ]; then
 	COUNTER=`expr $COUNTER + 1`
     done
 
+    $ECHO "ok"
+    $ECHO ""
+
+    $ECHO -n "Creating oer+MySQL.conf... "
+    $ECHO "mysql::$HOST::$DB::$DBUSER::$DBUSERPW" > sample-configuration/oer+MySQL.conf
+
+    RC=$?
+
+    if [ $RC -eq 1 ]; then
+	$ECHO "failed"
+	$ECHO ""
+	exit 1
+    fi
+
+    $ECHO "ident::$HANDLE" >> sample-configuration/oer+MySQL.conf
+
+    RC=$?
+
+    if [ $RC -eq 1 ]; then
+	$ECHO "failed"
+	$ECHO ""
+	exit 1
+    fi
+
     $ECHO "ok"
 fi
 
 $ECHO ""
-$ECHO -n "Creating oer+MySQL.conf... "
-$ECHO "mysql::$HOST::$DB::$DBUSER::$DBUSERPW" > sample-configuration/oer+MySQL.conf
 
-RC=$?
-
-if [ $RC -eq 1 ]; then
-    $ECHO "failed"
-    $ECHO ""
-    exit 1
-fi
-
-$ECHO "ident::$HANDLE" >> sample-configuration/oer+MySQL.conf
-
-RC=$?
-
-if [ $RC -eq 1 ]; then
-    $ECHO "failed"
-    $ECHO ""
-    exit 1
-fi
-
-$ECHO "ok"
-$ECHO ""
 exit 0
+
